function set_params(objects,varargin)
%SET_PARAMS Set multiple Simulink systems and block parameters.
%  SET_PARAMS(OBJECTS,'PARAMETER1',VALUE1,'PARAMETER2',VALUE2,...) is a 
%  vectorized form of SET_PARAM that works with cellstrs. It sets 
%  parameters within OBJECTS to the specified values. This enables the user
%  to change multiple objects in a single call, work directly with output 
%  from find_system, and easily work with blocks that contain carriage 
%  returns and/or apostrophes.
% 
% Examples:
%   set_params({'model/block1' 'model/subsystem1/block2'},'FontName','Courier New')
%   set_params(find_system(bdroot,'BlockType','Scope'),'BackgroundColor','lightBlue')
% 
% Coded by Will Campbell, MathWorks Inc.
% will.campbell@mathworks.com
% January 5, 2010
% Copyright 2009 - 2010 The MathWorks, Inc.

%% Error Handling
if iscellstr(objects)
    % everything is ok
elseif ischar(objects) % user supplies a character array that needs conversion to a cellstr
   objects = cellstr(objects); 
else
    error('Invalid Class for input "objects." Please provide a cellstr or character array.')
end

%% Algorithm
cr = sprintf('\n'); % carriage return variable
paramstr = comma_list(varargin); % convert parameters into a comma-delimited character array 
objects = strrep(objects,'''',''''''); % handle when people put apostrophes in their block names 

for i = 1:length(objects)
    object = objects{i};
    crs = strfind(object,cr);

    if isempty(crs)
        eval(['set_param(''' object ''',' paramstr ');'])
    elseif length(crs) == 1
        eval(['set_param([''' object(1:crs-1) ''',cr,''' object(crs+1:end) '''],' paramstr ');'])
    elseif length(crs) == 2
        eval(['set_param([''' object(1:crs(1)-1) ''',cr,''' object(crs(1)+1:crs(2)-1) ''',cr,''' object(crs(2)+1:end) '''],' paramstr ');'])
    elseif length(crs) == 3
        eval(['set_param([''' object(1:crs(1)-1) ''',cr,''' object(crs(1)+1:crs(2)-1) ''',cr,''' object(crs(2)+1:crs(3)-1) ''',cr,''' object(crs(3)+1:end) '''],' paramstr ');'])
    elseif length(crs) == 4
        eval(['set_param([''' object(1:crs(1)-1) ''',cr,''' object(crs(1)+1:crs(2)-1) ''',cr,''' object(crs(2)+1:crs(3)-1) ''',cr,''' object(crs(3)+1:crs(4)-1) ''',cr,''' object(crs(4)+1:end) '''],' paramstr ');'])
    elseif length(crs) == 5
        eval(['set_param([''' object(1:crs(1)-1) ''',cr,''' object(crs(1)+1:crs(2)-1) ''',cr,''' object(crs(2)+1:crs(3)-1) ''',cr,''' object(crs(3)+1:crs(4)-1) ''',cr,''' object(crs(4)+1:crs(5)-1) ''',cr,''' object(crs(5)+1:end) '''],' paramstr ');'])
    else
        error(['You''re testing my patience by having more than 5 carriage returns in ' object '.'])
    end
    
end
    